@@ -12,15 +12,15 @@ use constant DEBUG => 0;
 
 =head1 NAME
 
-Geo::Coder::List - Call many geocoders
+Geo::Coder::List - Call many Geo-Coders
 
 =head1 VERSION
 
-Version 0.21
+Version 0.22
 
 =cut
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 our %locations;
 
 =head1 SYNOPSIS
@@ -47,7 +47,7 @@ sub new {
 
 	# my %args = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
 
-	# return bless { %args, geocoders => [] }, $class;
+	# return bless { %args, geo_coders => [] }, $class;
 	return bless { }, $class;
 }
 
@@ -64,21 +64,21 @@ Different encoders can be preferred for different locations.
 For example this code uses geocode.ca for Canada and US addresses,
 and OpenStreetMap for other places:
 
-    my $geocoderlist = Geo::Coder::List->new()
+    my $geo_coderlist = Geo::Coder::List->new()
         ->push({ regex => qr/(Canada|USA|United States)$/, geocoder => Geo::Coder::CA->new() })
         ->push(Geo::Coder::OSM->new());
 
     # Uses Geo::Coder::CA, and if that fails uses Geo::Coder::OSM
-    my $location = $geocoderlist->geocode(location => '1600 Pennsylvania Ave NW, Washington DC, USA');
+    my $location = $geo_coderlist->geocode(location => '1600 Pennsylvania Ave NW, Washington DC, USA');
     # Only uses Geo::Coder::OSM
-    if($location = $geocoderlist->geocode('10 Downing St, London, UK')) {
+    if($location = $geo_coderlist->geocode('10 Downing St, London, UK')) {
         print 'The prime minister lives at co-ordinates ',
             $location->{geometry}{location}{lat}, ',',
             $location->{geometry}{location}{lng}, "\n";
     }
 
     # It is also possible to limit the number of enquires used by a particular encoder
-    $geocoderlist->push({ geocoder => Geo::Coder::GooglePlaces->new(key => '1234', limit => 100) });
+    $geo_coderlist->push({ geocoder => Geo::Coder::GooglePlaces->new(key => '1234', limit => 100) });
 
 =cut
 
@@ -95,7 +95,7 @@ sub push {
 Runs geocode on all of the loaded drivers.
 See L<Geo::Coder::GooglePlaces::V3> for an explanation
 
-The name of the geocoder that gave the result is put into the geocode element of the
+The name of the Geo-Coder that gave the result is put into the geocode element of the
 return value, if the value was retrieved from the cache the value will be undefined.
 
     if(defined($location->{'geocoder'})) {
@@ -178,13 +178,21 @@ sub geocode {
 			}
 			$geocoder->{'limit'}--;
 		}
-		if((ref($geocoder) eq 'HASH') && (my $regex = $geocoder->{'regex'})) {
-			print 'Consider ', ref($geocoder->{geocoder}), ": $regex\n" if(DEBUG);
-			if($location =~ $regex) {
-				$geocoder = $g->{'geocoder'};
-			} else {
-				next;
+		if(ref($geocoder) eq 'HASH') {
+			if(exists($geocoder->{'limit'}) && defined(my $limit = $geocoder->{'limit'})) {
+				print "limit: $limit\n" if(DEBUG);
+				if($limit <= 0) {
+					next ENCODER;
+				}
+				$geocoder->{'limit'}--;
 			}
+			if(my $regex = $geocoder->{'regex'}) {
+				print 'Consider ', ref($geocoder->{geocoder}), ": $regex\n" if(DEBUG);
+				if($location !~ $regex) {
+					next;
+				}
+			}
+			$geocoder = $g->{'geocoder'};
 		}
 		my @rc;
 		my $timetaken = Time::HiRes::time();
@@ -335,14 +343,14 @@ sub geocode {
 
 =head2 ua
 
-Accessor method to set the UserAgent object used internally by each of the geocoders. You
+Accessor method to set the UserAgent object used internally by each of the Geo-Coders. You
 can call I<env_proxy> for example, to get the proxy information from
 environment variables:
 
-    my $geocoderlist = Geo::Coder::List->new();
+    my $geocoder_list = Geo::Coder::List->new();
     my $ua = LWP::UserAgent->new();
     $ua->env_proxy(1);
-    $geocoderlist->ua($ua);
+    $geocoder_list->ua($ua);
 
 Note that unlike Geo::Coders, there is no read method, since that would be pointless.
 
